@@ -65,8 +65,13 @@ class Runner:
     def output(self, output_type, text, **extra):
         return self.output_buffer.put(output_type, text, **extra)
 
-    def execute(self, code_obj, mode=None):  # noqa
-        return eval(code_obj, self.console.locals)  # noqa
+    def execute(self, code_obj, mode=None, snoop_config=None):  # noqa
+        if mode == "snoop":
+            from .snoop import exec_snoop, SnoopStream
+            default_config = dict(columns=(), out=SnoopStream(self.output_buffer), color=False)
+            exec_snoop(self, code_obj, snoop_config=default_config | (snoop_config or {}))
+        else:
+            return eval(code_obj, self.console.locals)  # noqa
 
     @contextmanager
     def _execute_context(self):
@@ -77,17 +82,17 @@ class Runner:
                 self.output("traceback", **self.serialize_traceback(e))
         self.post_run()
 
-    def run(self, source_code, mode="exec"):
+    def run(self, source_code, mode="exec", snoop_config=None):
         code_obj = self.pre_run(source_code, mode=mode)
         with self._execute_context():
             if code_obj:
-                return self.execute(code_obj, mode)
+                return self.execute(code_obj, mode=mode, snoop_config=snoop_config)
 
-    async def run_async(self, source_code, mode="exec", top_level_await=True):
+    async def run_async(self, source_code, mode="exec", top_level_await=True, snoop_config=None):
         code_obj = self.pre_run(source_code, mode, top_level_await=top_level_await)
         with self._execute_context():
             if code_obj:
-                result = self.execute(code_obj, mode)
+                result = self.execute(code_obj, mode=mode, snoop_config=snoop_config)
                 while isinstance(result, Awaitable):
                     result = await result
                 return result
@@ -221,5 +226,6 @@ class PyodideRunner(PatchedStdinRunner, PatchedSleepRunner):  # noqa # pragma: n
         except Exception as e:
             try:
                 self.pyodide_error(e)
-            except (self.ServiceWorkerError, self.NoChannelError):
-                pass
+            except RuntimeError as re:
+                if re not in (self.ServiceWorkerError, self.NoChannelError):
+                    raise
